@@ -1,7 +1,7 @@
 package App::Wubot::Conditions;
 use Moose;
 
-our $VERSION = '0.3.7'; # VERSION
+our $VERSION = '0.3.8'; # VERSION
 
 use Scalar::Util qw/looks_like_number/;
 
@@ -14,7 +14,7 @@ App::Wubot::Conditions - evaluation conditions on reactor rules
 
 =head1 VERSION
 
-version 0.3.7
+version 0.3.8
 
 =head1 SYNOPSIS
 
@@ -104,6 +104,10 @@ sub istrue {
 
     return unless $condition;
 
+    # clean any whitespace surrounding conditions
+    $condition =~ s|^\s+||;
+    $condition =~ s|\s+$||;
+
     # if we have previously parsed this condition, look up the parsed
     # results in the cache.
     if ( $self->{cache}->{ $condition } ) {
@@ -114,7 +118,19 @@ sub istrue {
     my $parsed;
 
     # try to parse the rule
-    if ( $condition =~ m|^(.*)\s+AND\s+(.*)$| ) {
+    if ( $condition =~ s{\(\s+([^\(\)]+)\s+\)}{ my $expr = $1;
+
+                                          if ( $self->istrue( $expr, $message ) ) {
+                                              'TRUE';
+                                          } else {
+                                              'FALSE';
+                                          }
+                                      }e ) {
+
+        return $self->istrue( $condition, $message );
+
+    }
+    elsif ( $condition =~ m|^(.*)\s+AND\s+(.*)$| ) {
         my ( $first, $last ) = ( $1, $2 );
 
         return 1 if $self->istrue( $first, $message ) && $self->istrue( $last, $message );
@@ -126,6 +142,12 @@ sub istrue {
         return 1 if $self->istrue( $first, $message ) || $self->istrue( $last, $message );
         return;
     }
+    elsif ( $condition =~ m/^\s*TRUE\s*$/ ) {
+        $parsed = sub { return 1 };
+    }
+    elsif ( $condition =~ m/^\s*FALSE\s*$/ ) {
+        $parsed = sub { return };
+    }
     elsif ( $condition =~ m|^NOT\s+(.*)$| ) {
         return if $self->istrue( $1, $message );
         return 1;
@@ -204,7 +226,8 @@ sub istrue {
                          my $first;
                          if ( looks_like_number( $left ) ) {
                              $first = $left;
-                         } else {
+                         }
+                         else {
                              return unless exists $msg->{$left};
                              $first = $msg->{$left};
                              return unless looks_like_number( $first )
@@ -213,7 +236,8 @@ sub istrue {
                          my $second;
                          if ( looks_like_number( $right ) ) {
                              $second = $right;
-                         } else {
+                         }
+                         else {
                              return unless exists $msg->{$right};
                              $second = $msg->{$right};
                              return unless looks_like_number( $second )
@@ -221,11 +245,14 @@ sub istrue {
 
                          if ( $op eq ">" ) {
                              return 1 if $first > $second;
-                         } elsif ( $op eq ">=" ) {
+                         }
+                         elsif ( $op eq ">=" ) {
                              return 1 if $first >= $second;
-                         } elsif ( $op eq "<" ) {
+                         }
+                         elsif ( $op eq "<" ) {
                              return 1 if $first < $second;
-                         } elsif ( $op eq "<=" ) {
+                         }
+                         elsif ( $op eq "<=" ) {
                              return 1 if $first <= $second;
                          }
 
@@ -253,22 +280,25 @@ __END__
 
 =back
 
-=head1 LIMITATIONS
+=head1 PARENTHESES
 
-Unfortunately you can not (yet) use parens within conditions.
-Conditions are evaluated from left to right in order, e.g.
+You can now use parentheses within conditions.  For example:
 
-  - x is true AND y is true OR z is true
-    - evaluates as: x is true AND ( y is true OR z is true )
+  condition: ( x is false AND y is true ) OR z is true
 
-The main mechanism for nesting conditions is to use rule trees.  Child
+Note that you must always have at least one space after the opening
+parenthesis, and at least one space before the close parenthesis.  You
+will also need a space in-between a parentheses and the AND or OR that
+precedes or follows it.
+
+Another mechanism for nesting conditions is to use rule trees.  Child
 rules are only evaluated if the parent rule matches, so parent and
-child rules are logically combined by AND.  For example, set the field
-'foo' to the value '1' based on the following logic:
+child rules are logically combined by AND.  For example, the following
+condition:
 
-  ( x is true OR y is true ) AND ( a is true OR b is true )
+  condition: ( x is true OR y is true ) AND ( a is true OR b is true )
 
-You could create the following rule tree:
+is the equivalent of:
 
   rules:
     - name: check x and y
@@ -276,7 +306,3 @@ You could create the following rule tree:
       rules:
         - name: check a and b
           condition: a is true OR b is true
-          plugin: SetField
-          config:
-            field: foo
-            value: 1
