@@ -1,7 +1,7 @@
 package App::Wubot::Plugin::TestCase;
 use Moose;
 
-our $VERSION = '0.3.7'; # VERSION
+our $VERSION = '0.3.8'; # VERSION
 
 use App::Wubot::Logger;
 
@@ -14,6 +14,10 @@ sub check {
     my $cache  = $inputs->{cache};
     my $config = $inputs->{config};
 
+    if ( $config->{die} ) {
+        die "Testing Error"
+    }
+
     my $react;
 
     # just setting the cache params in the config
@@ -41,7 +45,7 @@ App::Wubot::Plugin::TestCase - a plugin for testing purposes
 
 =head1 VERSION
 
-version 0.3.7
+version 0.3.8
 
 =head1 DESCRIPTION
 
